@@ -1,6 +1,7 @@
 """Console script for op_env."""
 import argparse
 import json
+import pipes
 import sys
 from typing import List, Dict, Optional, Any, Union, Sequence
 from typing_extensions import TypedDict
@@ -60,17 +61,25 @@ def parse_argv(argv: List[str]) -> Arguments:
 
     subparsers = parser.add_subparsers(dest='operation')
     subparsers.required = True
+    run_desc = 'Run the specified command with the given environment variables'
     run_parser = subparsers.add_parser('run',
-                                       help='Run the specified command '
-                                       'with the given environment variables')
+                                       description=run_desc,
+                                       help=run_desc)
     add_environment_arguments(run_parser)
     run_parser.add_argument('command',
                             nargs='+',
                             help='Command to run with the environment set from 1Password')
+    json_desc = 'Produce simple JSON on stdout mapping requested env variables to values'
     json_parser = subparsers.add_parser('json',
-                                        help='Produce simple JSON on stdout '
-                                        'mapping requested env variables to values')
+                                        description=json_desc,
+                                        help=json_desc)
     add_environment_arguments(json_parser)
+    sh_desc = ("Produce commands on stdout that can be 'eval'ed to set "
+               "variables in current shell")
+    sh_parser = subparsers.add_parser('sh',
+                                      help=sh_desc,
+                                      description=sh_desc)
+    add_environment_arguments(sh_parser)
     return vars(parser.parse_args(argv[1:]))  # type: ignore
 
 
@@ -92,6 +101,11 @@ def process_args(args: Arguments) -> int:
         new_env = do_smart_lookups(args['environment'])
         print(json.dumps(new_env))
         return 0
+    elif args['operation'] == 'sh':
+        new_env = do_smart_lookups(args['environment'])
+        for envvar, envvalue in new_env.items():
+            print(f'{envvar}={pipes.quote(envvalue)}; export {envvar}')
+        return 0
     else:
         raise ValueError(f"Unknown operation: {args['operation']}")
 
